/**
 * Copyright (C) 2011 Angelo Zerr <angelo.zerr@gmail.com> and Pascal Leclercq <pascal.leclercq@gmail.com>
 *
 * All rights reserved.
 *
 * Permission is hereby granted, free  of charge, to any person obtaining
 * a  copy  of this  software  and  associated  documentation files  (the
 * "Software"), to  deal in  the Software without  restriction, including
 * without limitation  the rights to  use, copy, modify,  merge, publish,
 * distribute,  sublicense, and/or sell  copies of  the Software,  and to
 * permit persons to whom the Software  is furnished to do so, subject to
 * the following conditions:
 *
 * The  above  copyright  notice  and  this permission  notice  shall  be
 * included in all copies or substantial portions of the Software.
 *
 * THE  SOFTWARE IS  PROVIDED  "AS  IS", WITHOUT  WARRANTY  OF ANY  KIND,
 * EXPRESS OR  IMPLIED, INCLUDING  BUT NOT LIMITED  TO THE  WARRANTIES OF
 * MERCHANTABILITY,    FITNESS    FOR    A   PARTICULAR    PURPOSE    AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE,  ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package fr.opensagres.xdocreport.document.odt;

import java.io.IOException;

import org.apache.commons.io.IOUtils;

import fr.opensagres.xdocreport.converter.MimeMapping;
import fr.opensagres.xdocreport.core.document.DocumentKind;
import fr.opensagres.xdocreport.core.io.XDocArchive;
import fr.opensagres.xdocreport.document.AbstractXDocReport;
import fr.opensagres.xdocreport.document.odt.preprocessor.ODTPreprocessor;

/**
 * Open Office ODT report. For mime mapping please see {@see
 * http://framework.openoffice.org/documentation/mimetypes/mimetypes.html}.
 */
public class ODTReport extends AbstractXDocReport implements ODTConstants {

	private static final long serialVersionUID = 5974669564624835649L;

	private static final String[] DEFAULT_XML_ENTRIES = { CONTENT_XML_ENTRY,
			STYLES_XML_ENTRY };

	public String getKind() {
		return DocumentKind.ODT.name();
	}

	@Override
	protected void registerPreprocessors() {
		super.addPreprocessor(CONTENT_XML_ENTRY, ODTPreprocessor.INSTANCE);
	}

	@Override
	protected String[] getDefaultXMLEntries() {
		return DEFAULT_XML_ENTRIES;
	}

	// @Override
	// protected String[] getDefaultXMLEntriesForConversion() {
	// return DEFAULT_XML_ENTRIES_FOR_CONVERSION;
	// }

	public MimeMapping getMimeMapping() {
		return MIME_MAPPING;
	}

	public static boolean isODT(XDocArchive documentArchive) {
		try {
			if (!documentArchive.hasEntry(MIMETYPE)) {
				return false;
			}
			return ODT_MIMETYPE.equals(IOUtils.toString(documentArchive
					.getEntryReader(MIMETYPE)));
		} catch (IOException e) {
		}
		return false;
	}

}
